function createPlotsUpTo3D(X, Ycategories, features, ordinalOrder, w, w0)

    classes = categories(Ycategories);
    numClasses = numel(classes);
    numLearners = numClasses - 1; % ordinal training
    figure
    colormap(zeros(numClasses, 3));
    hsv_t = hsv;
    
    Xarray = table2array(X);
    

    % calculate subplot dimensions
    switch length(features)
        case 1
            spx = 1;
            spy = 1;
            spsize1 = 1;
        case 2     
            spx = 4;
            spy = 1;
            spsize1 = 1;
            spsize2 = 2:4;
        otherwise
            spx = 7;
            spy = 1;
            spsize1 = 1;
            spsize2 = 2:4;
            spsize3 = 5:7;
    end
    
    % we want to plot the hyperplanes in the color of one of the classes
    % they seperate. In order to do that, we have to convert the
    % ordinalOrder into a numeric vector
    
    if (exist('ordinalOrder','var'))
        ordinalOrderNumeric = zeros(length(ordinalOrder),1);
        for i=1:length(ordinalOrder)
            for j=1:length(ordinalOrder)
                if (string(classes{j}) == string(ordinalOrder{i}))
                  ordinalOrderNumeric(i) = j;
                end
            end
        end
    else
        ordinalOrderNumeric = 1:numClasses;
    end
        

    %% 1-D plot

    subplot(spx,spy,spsize1)
    hold on
    colormap(hsv_t);

    for i=1:numClasses
        plot(Xarray((Ycategories == classes(i)),features(1)),zeros(sum(Ycategories == classes(i)),1),'*', 'Color', hsv_t(i,:));
    end
    xlabel(['Feature ' num2str(features(1))]);

    %% 2-D plot

    if length(features) > 1
        subplot(spx,spy,spsize2)
        hold on
        colormap(hsv_t); 

        for i=1:numClasses
            plot(Xarray((Ycategories == classes(i)),features(1)),Xarray((Ycategories == classes(i)),features(2)),'*', 'Color', hsv_t(i,:));
        end

        xlabel(['Feature ' num2str(features(1))]);
        ylabel(['Feature ' num2str(features(2))]);
    end
    
    %% hyperplane plot in 2-D
    
    if length(features) == 2 && exist('ordinalOrder', 'var')...
                             && exist('w', 'var')...
                             && exist('w0', 'var')
        for i=1:numLearners
            fimplicit(@(x,y) w(1,i)*x + w(2,i)*y + w0(i),...
                'Color', hsv_t(ordinalOrderNumeric(i),:));
        end
    end

    %% 3-D plot

    if length(features) > 2
        sbp3 = subplot(spx,spy,spsize3);
        sbp3.Position(2) = 0.08; % pull plot down to make xlabel of plot 2 visible
        hold on
        colormap(hsv_t);
        grid on

        for i=1:numClasses
            plot3(Xarray((Ycategories == classes(i)),features(1)),Xarray((Ycategories == classes(i)),features(2)),Xarray((Ycategories == classes(i)),features(3)),'*', 'Color', hsv_t(i,:));
        end

        xlabel(['Feature ' num2str(features(1))]);
        ylabel(['Feature ' num2str(features(2))]);
        zlabel(['Feature ' num2str(features(3))]);
    end
    
     %% hyperplane plot in 3-D
    
    if length(features) == 3 && exist('ordinalOrder', 'var')...
                             && exist('w', 'var')...
                             && exist('w0', 'var')
        for i=1:numLearners
            fimplicit3(@(x,y,z) w(1,i)*x + w(2,i)*y + w(3,i)*z + w0(i),...
                'FaceColor', hsv_t(ordinalOrderNumeric(i),:));
        end
    end

    legend(char(classes),'location','southeast')
    
end
